"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InterfaceType = void 0;
const graphql_1 = require("graphql");
const __1 = require("../../../..");
const GQLObjectType_1 = require("./GQLObjectType");
class InterfaceType extends GQLObjectType_1.GQLObjectType {
    constructor(name) {
        super(name);
        this.setTypeResolver(this.defaultTypeResolver);
    }
    static create(nameOrType) {
        if (typeof nameOrType === "string") {
            return new InterfaceType(nameOrType);
        }
        else if (nameOrType instanceof __1.GQLType) {
            const obj = InterfaceType.create(nameOrType.name)
                .setMeta(nameOrType.meta)
                .setDescription(nameOrType.description);
            if (nameOrType instanceof __1.InputType) {
                obj.setFields(...nameOrType.fields.map((f) => __1.Field.create(f)));
            }
            else if (nameOrType instanceof GQLObjectType_1.GQLObjectType) {
                obj.setFields(...nameOrType.fields);
            }
            return obj;
        }
        else {
            const t = InterfaceType.create(nameOrType.name);
            t._classType = nameOrType;
            return t;
        }
    }
    build() {
        const built = new graphql_1.GraphQLInterfaceType({
            name: this.name,
            description: this.description,
            resolveType: this._typeResolver,
            fields: () => this.getFields(),
            extensions: [],
        });
        this._built = built;
        return this._built;
    }
    /**
     * Set the type of the field
     * @param typeResolver the field resolver
     */
    setTypeResolver(typeResolver) {
        this._typeResolver = typeResolver;
        return this;
    }
    /**
     * Add a suffix to the name of your type ("Interface" by default)
     * @param suffix The suffix to add to the name
     */
    suffix(suffix = "Interface") {
        return this.setName(this.name + suffix);
    }
    copy() {
        return InterfaceType.create(this);
    }
    convert(to) {
        return to.create(this);
    }
    defaultTypeResolver(obj) {
        return __1.TypeResolver.resolve(obj, []);
    }
}
exports.InterfaceType = InterfaceType;
//# sourceMappingURL=InterfaceType.js.map