"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TypeParser = void 0;
const graphql_1 = require("graphql");
const __1 = require("..");
class TypeParser {
    static parse(type, notNullableByDefault = false) {
        let finalType;
        if (Array.isArray(type)) {
            finalType = this.parse(type[0]);
            finalType = graphql_1.GraphQLList(finalType);
        }
        if (type instanceof __1.GQLAnyType) {
            finalType = type.built;
        }
        switch (type) {
            case String:
                finalType = graphql_1.GraphQLString;
                break;
            case Number:
                finalType = graphql_1.GraphQLFloat;
                break;
            case Boolean:
                finalType = graphql_1.GraphQLBoolean;
            case Date:
                finalType = __1.DateTime;
                break;
        }
        if (notNullableByDefault) {
            if (type instanceof __1.NullableType) {
                finalType = this.parse(type.type);
            }
            else {
                finalType = graphql_1.GraphQLNonNull(finalType);
            }
        }
        else {
            if (type instanceof __1.NotNullableType) {
                finalType = graphql_1.GraphQLNonNull(this.parse(type.type));
            }
        }
        return finalType;
    }
}
exports.TypeParser = TypeParser;
//# sourceMappingURL=TypeParser.js.map